Enumeration
AdapFlapTransitionType
deprecated: 1.4
Description [src]
Describes transitions types of a AdapFlap widget.
It determines the type of animation when transitioning between children in a
AdapFlap widget, as well as which areas can be swiped via
AdapFlap:swipe-to-open and AdapFlap:swipe-to-close.
Deprecated since: 1.4
See the migration guide.
Members
-
ADAP_FLAP_TRANSITION_TYPE_OVER -
The flap slides over the content, which is dimmed. When folded, only the flap can be swiped.
- Value:
0 - Available since: 1
- Value:
-
ADAP_FLAP_TRANSITION_TYPE_UNDER -
The content slides over the flap. Only the content can be swiped.
- Value:
1 - Available since: 1
- Value:
-
ADAP_FLAP_TRANSITION_TYPE_SLIDE -
The flap slides offscreen when hidden, neither the flap nor content overlap each other. Both widgets can be swiped.
- Value:
2 - Available since: 1
- Value: